Documentation Home — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Documentation Home

Askbot is an open source Question and Answer (Q&A) forum project inspired by StackOverflow and YahooAnswers.

This version of Askbot supports only Django 1.8.

To upgrade, or select version of Askbot working with earlier versions of Django, please follow `the instructions`_.

It is quick and easy to install and deploy askbot on your site. Have questions? - please ask at the forum or by email at admin@askbot.org

- Install the software
- Create the database
- Create and configure the site files
- Initialize the database tables
- Deploy on a webserver
- Upgrades
- Import data (StackExchange & ZenDesk)
- Moderation
- Analytics
- Appendix A: Maintenance procedures
- Appendix B: Optional modules
- Appendix C: Api
- Appendix D: Askbot as reusable Django application
- Appendix E: Customizing skin in askbot
- Appendix F: Intranet setup
- Appendix G: Language support in Askbot
- Appendix H: Migration from MySQL to PostgreSQL
- Footnotes
- Contributors
- Changelog

Some background information: Askbot is written in Python on top of the Django platform. Code of Askbot grew out of CNPROG project originally written by Mike Chen and Sailing Cai.